@@ -195,8 +195,8 @@ class TradeClient(object):
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ASSET, req)
 
     def query_order(self,
-                    instrument_id=None,
                     exchange_id=None,
+                    instrument_id=None,
                     order_sys_id=None,
                     insert_time_start=None,
                     insert_time_end=None,
@@ -214,8 +214,11 @@ class TradeClient(object):
         Returns:OrderInfo Rsp
 
         '''
-        if instrument_id is not None:
-            exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
 
         req = trade_req.make_query_order_req(investor_key=self._investor_key,
                                              instrument_id=instrument_id,
@@ -226,6 +229,19 @@ class TradeClient(object):
                                              client_id=client_id)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ORDER, req)
 
+    def query_trade(self, instrument_id, exchange_id=None, trade_id=None, trade_time_start=None, trade_time_end=None,
+                    client_id=None, status=None):
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
+        req = trade_req.make_query_report_req(investor_key=self._investor_key, instrument_id=instrument_id,
+                                              exchange_id=exchange_id, trade_id=trade_id,
+                                              trade_time_start=trade_time_start, trade_time_end=trade_time_end,
+                                              client_id=client_id, status=status)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_ORDER_QUERY_TRADE, req)
+
     def query_position_detail(self,
                               instrument_id=None,
                               exchange_id=None,
@@ -255,23 +271,20 @@ class TradeClient(object):
                        historical_date=None,
                        client_id=None):
         '''
-        查持仓（异步）
+        查持仓
         Args:
             instrument_id:合约
             exchange_id:交易所
             historical_date:历史日期
             client_id:顶点
-
-        Returns:future对象，可调用then方法
-
         '''
-
+        exchange_id = parse_exchange_id(instrument_id)
         req = trade_req.make_query_position_req(investor_key=self._investor_key,
                                                 instrument_id=instrument_id,
                                                 exchange_id=exchange_id,
                                                 historical_date=historical_date,
                                                 client_id=client_id)
-        return self._rpc_call_mf(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION, req)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION, req)
 
     def order_insert(self,
                      instrument_id,
@@ -298,7 +311,8 @@ class TradeClient(object):
                      is_change_order=None,
                      new_order_price_type=None,
                      new_limit_price=None,
-                     price_tick_num=None):
+                     price_tick_num=None,
+                     exchange_id=None):
         '''
         报单
         Args:
@@ -331,7 +345,11 @@ class TradeClient(object):
         Returns:OrderInsert Rsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         if order_price_type is trade_req.OrderPriceType.OrderPriceType_LimitPrice and limit_price is None:
             return -1, u'价格类型为限价，请填写价格'
 
@@ -366,10 +384,10 @@ class TradeClient(object):
 
     def order_cancel(self,
                      order_no,
-                     cancel_order_no=None,
                      order_sys_id=None,
+                     exchange_id=None,
+                     cancel_order_no=None,
                      instrument_id=None,
-                     investor_id=None,
                      client_id=None,
                      is_change_order=None,
                      volume_total_original=None,
@@ -394,14 +412,18 @@ class TradeClient(object):
         Returns:OrderCancel Rsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         req = trade_req.make_order_cancel_req(investor_key=self._investor_key,
                                               cancel_order_no=cancel_order_no,
                                               order_no=order_no,
                                               exchange_id=exchange_id,
                                               order_sys_id=order_sys_id,
                                               instrument_id=instrument_id,
-                                              investor_id=investor_id,
+                                              investor_id=self._investor_id,
                                               client_id=client_id,
                                               is_change_order=is_change_order,
                                               volume_total_original=volume_total_original,
@@ -410,7 +432,7 @@ class TradeClient(object):
                                               price_tick_num=price_tick_num)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_CANCEL_ORDER, req)
 
-    def query_instrument(self, instrument_id):
+    def query_instrument(self, instrument_id, exchange_id=None):
         '''
         查询合约
         Args:
@@ -419,16 +441,20 @@ class TradeClient(object):
         Returns:QueryInstrumentRsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         req = trade_req.make_query_instrument_req(investor_key=self._investor_key,
                                                   exchange_id=exchange_id,
                                                   instrument_id=instrument_id)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_INSTRUMENT, req)
 
-    def query_margin_rate_req(self,
-                              instrument_id,
-                              hedge_flag=trade_req.HedgeFlagType.HedgeFlag_Speculation,
-                              exchange_id=None):
+    def query_margin_rate(self,
+                          instrument_id,
+                          hedge_flag=trade_req.HedgeFlagType.HedgeFlag_Speculation,
+                          exchange_id=None):
         '''
         查询保证金率
         Args:
@@ -439,7 +465,11 @@ class TradeClient(object):
         Returns: QueryMarginRate Rsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         req = trade_req.make_query_margin_rate_req(investor_key=self._investor_key,
                                                    instrument_id=instrument_id,
                                                    hedge_flag=hedge_flag,
@@ -458,7 +488,11 @@ class TradeClient(object):
         Returns:QueryCommissionRate Rsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         req = trade_req.make_query_commission_rate_req(investor_key=self._investor_key,
                                                        instrument_id=instrument_id,
                                                        exchange_id=exchange_id)
@@ -466,12 +500,13 @@ class TradeClient(object):
 
     def query_max_order_volume(self,
                                instrument_id,
-                               exchange_id,
                                direction,
-                               offset_flag,
-                               max_volume,
-                               investor_unit_id=None,
-                               limit_price=None
+                               exchange_id=None,
+                               limit_price=None,
+                               offset_flag=None,
+                               hedge_flag=None,
+                               max_volume=None,
+                               investor_unit_id=None
                                ):
         '''
         查询最大保单数量
@@ -487,11 +522,16 @@ class TradeClient(object):
         Returns:QueryMaxOrderVolume Rsp
 
         '''
-        exchange_id = parse_exchange_id(instrument_id)
+        if exchange_id is None:
+            if instrument_id is not None:
+                exchange_id = parse_exchange_id(instrument_id)
+            else:
+                return -1, u'请填写交易所或合约代码'
         req = trade_req.make_query_max_order_volume_req(investor_key=self._investor_key,
                                                         instrument_id=instrument_id,
                                                         exchange_id=exchange_id,
                                                         direction=direction,
+                                                        hedge_flag=hedge_flag,
                                                         offset_flag=offset_flag,
                                                         max_volume=max_volume,
                                                         investor_unit_id=investor_unit_id,
@@ -500,6 +540,7 @@ class TradeClient(object):
 
     def query_trading_code(self,
                            exchange_id=None,
+                           broker_id=None,
                            client_id=None,
                            is_active=None,
                            client_id_type=None,
@@ -518,6 +559,7 @@ class TradeClient(object):
         '''
         req = trade_req.make_qry_trading_code_req(investor_key=self._investor_key,
                                                   exchange_id=exchange_id,
+                                                  broker_id=broker_id,
                                                   client_id=client_id,
                                                   is_active=is_active,
                                                   client_id_type=client_id_type,
@@ -525,8 +567,7 @@ class TradeClient(object):
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRADING_CODE, req)
 
     def query_investor(self,
-                       broker_id,
-                       investor_id):
+                       broker_id):
         '''
         查询投资者
         Args:
@@ -538,15 +579,14 @@ class TradeClient(object):
         '''
         req = trade_req.make_query_investor_req(investor_key=self._investor_key,
                                                 broker_id=broker_id,
-                                                investor_id=investor_id)
+                                                investor_id=self._investor_id)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_INVESTOR, req)
 
     def confirm_settlement_info(self,
                                 broker_id,
-                                investor_id,
                                 trading_day=None,
                                 account_id=None,
-                                currency_id=None, ):
+                                currency_id=None):
         '''
         投资者结算结果确认
         Args:
@@ -561,7 +601,7 @@ class TradeClient(object):
         '''
         req = trade_req.make_confirm_settlement_info_req(investor_key=self._investor_key,
                                                          broker_id=broker_id,
-                                                         investor_id=investor_id,
+                                                         investor_id=self._investor_id,
                                                          trading_day=trading_day,
                                                          account_id=account_id,
                                                          currency_id=currency_id)
@@ -569,10 +609,11 @@ class TradeClient(object):
 
     def query_settlement_info(self,
                               broker_id,
-                              investor_id,
                               trading_day,
                               account_id=None,
                               currency_id=None,
+                              start_date=None,
+                              end_date=None
                               ):
         '''
         查询投资者结算结果
@@ -588,18 +629,18 @@ class TradeClient(object):
         '''
         req = trade_req.make_query_settlement_info_req(investor_key=self._investor_key,
                                                        broker_id=broker_id,
-                                                       investor_id=investor_id,
+                                                       investor_id=self._investor_id,
                                                        trading_day=trading_day,
                                                        account_id=account_id,
-                                                       currency_id=currency_id)
+                                                       currency_id=currency_id, start_date=start_date,
+                                                       end_date=end_date)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_SETTLEMENT_INFO, req)
 
-    def query_settlement_confirm(self,
-                                 broker_id,
-                                 investor_id,
-                                 account_id=None,
-                                 currency_id=None,
-                                 ):
+    def query_settlement_info_confirm(self,
+                                      broker_id,
+                                      account_id=None,
+                                      currency_id=None
+                                      ):
         '''
         查询投资者结算结果
         Args:
@@ -611,11 +652,12 @@ class TradeClient(object):
         Returns:QuerySettlementInfoConfirm Rsp
 
         '''
-        req = trade_req.make_query_settlement_info_req(investor_key=self._investor_key,
-                                                       broker_id=broker_id,
-                                                       investor_id=investor_id,
-                                                       account_id=account_id,
-                                                       currency_id=currency_id)
+        req = trade_req.make_query_settlement_info_confirm_req(investor_key=self._investor_key,
+                                                               broker_id=broker_id,
+                                                               investor_id=self._investor_id,
+                                                               account_id=account_id,
+                                                               currency_id=currency_id
+                                                               )
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_SETTLEMENT_INFO_CONFIRM, req)
 
     def user_password_update(self,
@@ -655,3 +697,59 @@ class TradeClient(object):
                                                           account=account,
                                                           bank_account=bank_account)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_BANK_ACCOUNT_MONEY, req)
+
+    def from_bank_to_future(self, bank_id, currency_id, bank_branch_id, password, bank_password, trade_amount,
+                            bank_account, account, broker_branch_id=None):
+        req = trade_req.make_from_bank_to_future_req(investor_key=self._investor_key, bank_id=bank_id,
+                                                     currency_id=currency_id, bank_branch_id=bank_branch_id,
+                                                     password=password, bank_password=bank_password,
+                                                     account=account,
+                                                     trade_amount=trade_amount, bank_account=bank_account,
+                                                     broker_branch_id=broker_branch_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_FROM_BANK_TO_FUTURE, req)
+
+    def from_future_to_bank(self, bank_id, currency_id, bank_branch_id, password, bank_password, trade_amount, account,
+                            transfer_direction,
+                            bank_account, broker_branch_id=None):
+        req = trade_req.make_from_future_to_bank_req(investor_key=self._investor_key, bank_id=bank_id,
+                                                     currency_id=currency_id, bank_branch_id=bank_branch_id,
+                                                     password=password, bank_password=bank_password,
+                                                     trade_amount=trade_amount, account=account,
+                                                     transfer_direction=transfer_direction,
+                                                     bank_account=bank_account, broker_branch_id=broker_branch_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_FROM_FUTURE_TO_BANK, req)
+
+    def query_contract_bank(self):
+        req = trade_req.make_query_contract_bank_req(investor_key=self._investor_key)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_CONTRACT_BANK, req)
+
+    def query_account_register(self, currency_id=None):
+        req = trade_req.make_query_accountregister_req(investor_key=self._investor_key, currency_id=currency_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ACCOUNT_REGISTER, req)
+
+    def query_transfer_serial(self, bank_id=None, currency_id=None, start_date=None, end_date=None):
+        req = trade_req.make_query_transfer_serial_req(investor_key=self._investor_key, bank_id=bank_id,
+                                                       currency_id=currency_id, start_date=start_date,
+                                                       end_date=end_date)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRANSFER_SERIAL, req)
+
+    def query_trading_notice(self, investor_unit_id):
+        req = trade_req.make_query_trading_notice_req(investor_key=self._investor_key,
+                                                      investor_unit_id=investor_unit_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRADING_NOTICE, req)
+
+    def make_query_notice(self):
+        req = trade_req.make_query_notice_req(investor_key=self._investor_key)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_NOTICE, req)
+
+    def trading_account_password_update(self, old_password, new_password, currency_id):
+        req = trade_req.make_trading_account_password_update_req(investor_key=self._investor_key,
+                                                                 old_password=old_password, new_password=new_password,
+                                                                 currency_id=currency_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_TRADING_ACCOUNT_PASSWORD_UPDATE, req)
+
+    def query_cfmmc_account_token(self, broker_id=None, investor_unit_id=None, investor_id=None):
+        req = trade_req.make_query_CFMMC_trading_account_token_req(investor_key=self._investor_key, broker_id=broker_id,
+                                                                   investor_unit_id=investor_unit_id,
+                                                                   investor_id=investor_id)
+        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_CFMMC_ACCOUNT_TOKEN, req)
